<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Gillepsie
 * @subpackage Vpc_Gillepsie/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Gillepsie
 * @subpackage Vpc_Gillepsie/admin
 * @author     orion <help@orionorigin.com>
 */
class Vpc_Gillepsie_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

	$this->plugin_name = $plugin_name;
	$this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

	/**
	 * This function is provided for demonstration purposes only.
	 *
	 * An instance of this class should be passed to the run() function
	 * defined in Vpc_Gillepsie_Loader as all of the hooks are defined
	 * in that particular class.
	 *
	 * The Vpc_Gillepsie_Loader will then create the relationship
	 * between the defined hooks and the functions defined in this
	 * class.
	 */
	wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/vpc-gillepsie-admin.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

	/**
	 * This function is provided for demonstration purposes only.
	 *
	 * An instance of this class should be passed to the run() function
	 * defined in Vpc_Gillepsie_Loader as all of the hooks are defined
	 * in that particular class.
	 *
	 * The Vpc_Gillepsie_Loader will then create the relationship
	 * between the defined hooks and the functions defined in this
	 * class.
	 */
	wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/vpc-gillepsie-admin.js', array('jquery'), $this->version, false);
    }

    function vpc_configuration_dimmension_metabox_order($order) {
	$order["advanced"] = "vpc-config-preview-box,vpc-config-settings-box,vpc-config-initials-box,vpc-config-conditional-rules-box,submitdiv";
	return $order;
    }

    public function additional_configuration_metabox() {
	add_meta_box(
		'vpc-config-initials-box', __('Configuration initials', 'vcp-gillepsie'), array($this, 'get_initial_info_fields'), 'vpc-config'
	);
    }

    public function get_initial_info_fields() {
	$begin = array(
	    'type' => 'sectionbegin',
	    'id' => 'vpc-config-initial-info'
	);
	$end = array('type' => 'sectionend');

	$initial_field_label = array(
	    'title' => __('Label Value', 'vcp-gillepsie'),
	    'type' => 'text',
	    'name' => 'vpc-config[initial][label]',
	);
	$initial_font_name = array(
	    'title' => __('Font family', 'vcp-gillepsie'),
	    'type' => 'text',
	    'name' => 'font-name',
	);
	$initial_font_url = array(
	    'title' => __('font url', 'vcp-gillepsie'),
	    'type' => 'text',
	    'name' => 'font-url',
	);

	$initial_fonts = array(
	    'title' => __('Initials fonts', 'vcp-gillepsie'),
	    'name' => 'vpc-config[initial][fonts]',
	    'type' => 'repeatable-fields',
	    'fields' => array($initial_font_name, $initial_font_url),
	    'desc' => __('Add fonts', 'vcp-gillepsie'),
	    'ignore_desc_col' => false,
	    'add_btn_label' => __('Add font', 'vcp-gillepsie')
	);

	$initial_position_label = array(
	    'title' => __('Position label', 'vcp-gillepsie'),
	    'type' => 'text',
	    'name' => 'label',
	);
	$initial_position_preview_css = array(
	    'title' => __('Position preview css', 'vcp-gillepsie'),
	    'type' => 'textarea',
	    'name' => 'preview-css',
	);
	$initial_position = array(
	    'title' => __('Initials fonts', 'vcp-gillepsie'),
	    'name' => 'vpc-config[initial][positions]',
	    'type' => 'repeatable-fields',
	    'fields' => array($initial_position_label, $initial_position_preview_css),
	    'desc' => __('Add positions', 'vcp-gillepsie'),
	    'ignore_desc_col' => false,
	    'add_btn_label' => __('Add position', 'vcp-gillepsie')
	);

	$settings = array(
	    $begin,
	    $initial_field_label,
	    $initial_fonts,
	    $initial_position,
	    $end
	);
	echo o_admin_fields($settings);
	global $o_row_templates;
	?>
	<script>
	    var o_rows_tpl =<?php echo json_encode($o_row_templates); ?>;
	</script>
	<?php
    }

    public function add_gillepsi_skin($skins) {
	$skins['VPC_Gillepsie_Skin'] = __('VPC Gillepsie Skin', 'vpc-gillepsie');
	return$skins;
    }

}
