<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Gillepsie
 * @subpackage Vpc_Gillepsie/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Gillepsie
 * @subpackage Vpc_Gillepsie/public
 * @author     orion <help@orionorigin.com>
 */
class Vpc_Gillepsie_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

	$this->plugin_name = $plugin_name;
	$this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

	/**
	 * This function is provided for demonstration purposes only.
	 *
	 * An instance of this class should be passed to the run() function
	 * defined in Vpc_Gillepsie_Loader as all of the hooks are defined
	 * in that particular class.
	 *
	 * The Vpc_Gillepsie_Loader will then create the relationship
	 * between the defined hooks and the functions defined in this
	 * class.
	 */
	wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/vpc-gillepsie-public.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

	/**
	 * This function is provided for demonstration purposes only.
	 *
	 * An instance of this class should be passed to the run() function
	 * defined in Vpc_Gillepsie_Loader as all of the hooks are defined
	 * in that particular class.
	 *
	 * The Vpc_Gillepsie_Loader will then create the relationship
	 * between the defined hooks and the functions defined in this
	 * class.
	 */
	wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/vpc-gillepsie-public.js', array('jquery'), $this->version, false);
    }

    public function get_configuration_custom_fields($config) {
	$config_initials = get_proper_value($config, 'initial');
	$initials_label = get_proper_value($config_initials, 'label');
	$initials_positions = get_proper_value($config_initials, 'positions');
	$initials_fonts = get_proper_value($config_initials, 'fonts');
	?>
	<div class="vpc-initials-screen-wrap">
	    <div>
		 <h3><?php echo $initials_label; ?></h3>
	    </div>
	   
	    <div class="vpc-initial-txt-field-wrap"> 
		<input type="text" id="vpc-initial-field" class="vpc-text-input" name="<?php echo $initials_label; ?>"/>
	    </div>
	    <div class="vpc-initial-fonts-label-wrap">
		<label for="vpc-initials-font"> <?php esc_html_e('Initials font', 'vpc-gillepsie'); ?> </label>
	    </div>
	    <div class="vpc-initial-fonts-select-wrap ">
		<select name="<?php esc_html_e('Initials font', 'vpc-gillepsie'); ?>" id="vpc-initials-font">
		    <?php
		    foreach ($initials_fonts as $key => $initials_font) {
			$font_label = get_proper_value($initials_font, 'font-name');
			$font_url = get_proper_value($initials_font, 'font-url');
			wp_enqueue_style($font_label, $font_url);
			echo '<option value="' . $font_label . '">' . $font_label . '</option>';
		    }
		    ?>
		</select>
	    </div>


	    <div class="vpc-initial-position-label-wrap">
		<label for="vpc-initials-position"> <?php esc_html_e('Initials potition', 'vpc-gillepsie'); ?> </label>
	    </div>
	    <div class="vpc-initial-position-select-wrap">
		<select name="<?php esc_html_e('Initials potition', 'vpc-gillepsie'); ?>" id="vpc-initials-position">
		    <?php
		    foreach ($initials_positions as $key => $initials_position) {
			$position_label = get_proper_value($initials_position, 'label');
			$position_css = get_proper_value($initials_position, 'preview-css');
			echo '<option value="' . $position_label . '" data-preview-css = "'.$position_css.'">' . $position_label . '</option>';
		    }
		    ?>
		</select>
	    </div>


	</div>

	<?php
    }

}
